@@ -24,7 +24,7 @@
 #include "mainpagequery.h"
 #include "relship.h"
 #include <bonobo.h>
-#include <libgnomedb/libgnomedb.h>
+#include <libgnomedb/gnome-db-login-dialog.h>
 #include "item-selector.h"
 #include "object-selector.h"
 #include "settings.h"
